==> react-ui-library-0.8.1.tgz: package/src/components/Fonts.js <==
import React, { Component } from 'react'
import { css } from 'glamor'

const createURLS = (path) => `
  url(https://static.segment.com/fonts/${path}.woff2) format('woff2'),
  url(https://static.segment.com/fonts/${path}.woff) format('woff')
`

class Fonts extends Component {
  componentDidMount () {
    css.fontFace({
      fontFamily: 'Droid Sans Mono',
      src: `local('Droid Sans Mono'),
          ${createURLS('droid-sans-mono/droid-sans-mono')}`,
      fontStyle: 'normal',
      fontWeight: '400'
    })

    css.fontFace({
      fontFamily: 'Segment Aleo',
      src: `local('Aleo'),
        ${createURLS('aleo/aleo')}`,
      fontStyle: 'normal',
      fontWeight: '400'
    })

    css.fontFace({
      fontFamily: 'Segment Aleo',
      src: `local('Aleo'),
        ${createURLS('aleo/aleo')}`,
      fontStyle: 'normal',
      fontWeight: '400'
    })

    css.fontFace({
      fontFamily: 'Segment Circular Std',
      src: `local('Circular Std Book'),
           local('CircularStd-Book'),
           ${createURLS('circular/circular-std-book')}`,
      fontStyle: 'normal',
      fontWeight: '400'
    })

    css.fontFace({
      fontFamily: 'Segment Circular Std',
      src: `local('Circular Std Book Italic'),
           local('CircularStd-BookItalic'),
           ${createURLS('circular/circular-std-book-italic')}`,
      fontStyle: 'italic',
      fontWeight: '400'
    })

    css.fontFace({
      fontFamily: 'Segment Circular Std',
      src: `local('Circular Std Medium'), /* Medium has a spaced font name ¯\_(ツ)_/¯ */
           local('CircularStd-Medium'),
           ${createURLS('circular/circular-std-medium')}`,
      fontStyle: 'normal',
      fontWeight: '500'
    })

    css.fontFace({
      fontFamily: 'Segment Circular Std',
      src: `local('Circular Std Bold'),
           local('CircularStd-Bold'),
           ${createURLS('circular/circular-std-bold')}`,
      fontStyle: 'normal',
      fontWeight: '600'
    })

    css.fontFace({
      fontFamily: 'Segment Circular Std',
      src: `local('Circular Std Black'),
           local('CircularStd-Black'),
           ${createURLS('circular/circular-std-black')}`,
      fontStyle: 'normal',
      fontWeight: '900'
    })
  }

  render () {
    return null
  }
}

export default Fonts

==> react-ui-library-7.3.0.tgz: package/src/components/Fonts.js <==
import { Component } from 'react'
import { css } from 'glamor'

const createURLS = (path) => `
  url(https://static.segment.com/fonts/${path}.woff2) format('woff2'),
  url(https://static.segment.com/fonts/${path}.woff) format('woff')
`

class Fonts extends Component {
  componentDidMount () {
    css.fontFace({
      fontFamily: 'Droid Sans Mono',
      src: `local('Droid Sans Mono'),
          ${createURLS('droid-sans-mono/droid-sans-mono')}`,
      fontStyle: 'normal',
      fontWeight: '400'
    })

    css.fontFace({
      fontFamily: 'Segment Aleo',
      src: `local('Aleo'),
        ${createURLS('aleo/aleo')}`,
      fontStyle: 'normal',
      fontWeight: '400'
    })

    css.fontFace({
      fontFamily: 'Segment Aleo',
      src: `local('Aleo'),
        ${createURLS('aleo/aleo')}`,
      fontStyle: 'normal',
      fontWeight: '400'
    })

    css.fontFace({
      fontFamily: 'Segment Circular Std',
      src: `local('Circular Std Book'),
           local('CircularStd-Book'),
           ${createURLS('circular/circular-std-book')}`,
      fontStyle: 'normal',
      fontWeight: '400'
    })

    css.fontFace({
      fontFamily: 'Segment Circular Std',
      src: `local('Circular Std Book Italic'),
           local('CircularStd-BookItalic'),
           ${createURLS('circular/circular-std-book-italic')}`,
      fontStyle: 'italic',
      fontWeight: '400'
    })

    css.fontFace({
      fontFamily: 'Segment Circular Std',
      src: `local('Circular Std Medium'), /* Medium has a spaced font name ¯\\_(ツ)_/¯ */
           local('CircularStd-Medium'),
           ${createURLS('circular/circular-std-medium')}`,
      fontStyle: 'normal',
      fontWeight: '500'
    })

    css.fontFace({
      fontFamily: 'Segment Circular Std',
      src: `local('Circular Std Bold'),
           local('CircularStd-Bold'),
           ${createURLS('circular/circular-std-bold')}`,
      fontStyle: 'normal',
      fontWeight: '600'
    })

    css.fontFace({
      fontFamily: 'Segment Circular Std',
      src: `local('Circular Std Black'),
           local('CircularStd-Black'),
           ${createURLS('circular/circular-std-black')}`,
      fontStyle: 'normal',
      fontWeight: '900'
    })
  }

  render () {
    return null
  }
}

export default Fonts
